CedarBackup3.actions.collect — cedar-backup3 3.10.0 documentation

# CedarBackup3.actions.collect

Implements the standard ‘collect’ action. :author: Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.actions.collect.logger

CedarBackup3.actions.collect.executeCollect(configPath, options, config)

  Executes the collect backup action.

  Note: When the collect action is complete, we will write a collect indicator to the collect directory, so it’s obvious that the collect action has completed. The stage process uses this indicator to decide whether a peer is ready to be staged.

  Parameters:

    - configPath (String representing a path on disk) – Path to configuration file on disk

    - options (Options object) – Program command-line options

    - config (Config object) – Program configuration

  Raises:

    - ValueError – Under many generic error conditions

    - TarError – If there is a problem creating a tar file